@@ -1,5 +1,6 @@
 /*********************************************************
- * Copyright (C) 1998-2022 VMware, Inc. All rights reserved.
+ * Copyright (c) 1998-2024 Broadcom. All rights reserved.
+ * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -1785,6 +1786,16 @@ File_CreateDirectoryHierarchyEx(const char *pathName,   // IN:
             temp = NULL;
          }
       } else {
+         /*
+          * For DELL thinOS, calling `mkdir' for an existing directory in a
+          * path which we do not have write permission will return with EACCES
+          * instead of EEXIST. Here we test again using `euidaccess' to work
+          * around this.
+          */
+         if (err == EACCES && Posix_EuidAccess(temp, F_OK) == 0) {
+            err = EEXIST;
+         }
+
          if (err == EEXIST) {
             FileData fileData;
 
@@ -2409,6 +2420,7 @@ FileRotateByRename(const char *fileName,  // IN: full path to file
 
       ASSERT(dst != fileName);
       Posix_Free(dst);
+      /* coverity[use_after_free] */
       dst = src;
    }
 }
@@ -2811,3 +2823,32 @@ File_IsSubPathOf(const char *base, // IN: the base path to test against.
    return isSubPath;
 }
 
+
+#if !defined(VMX86_SERVER)
+
+/*
+ *---------------------------------------------------------------------------
+ *
+ * File_DoesVolumeSupportConvertBlocks --
+ *
+ *     Does the volume support the new convert block allocation
+ *     IOCTL? (Always FALSE for now on non-VMFS.)
+ *
+ * Results:
+ *     TRUE   Yes
+ *     FALSE  No
+ *
+ * Side effects:
+ *     None
+ *
+ *---------------------------------------------------------------------------
+ */
+
+Bool
+File_DoesVolumeSupportConvertBlocks(const char *pathName)  // IN:
+{
+   UNUSED_VARIABLE(pathName);
+   return FALSE;
+}
+
+#endif
