@@ -1,5 +1,6 @@
 /*********************************************************
- * Copyright (c) 1998-2020,2023 VMware, Inc. All rights reserved.
+ * Copyright (c) 1998-2024 Broadcom. All Rights Reserved.
+ * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -381,7 +382,10 @@ int File_MakeSafeTemp(const char *tag,
 
 Bool File_DoesVolumeSupportAcls(const char *pathName);
 
-Bool File_IsSubPathOf(const char *base, const char *path);
+Bool File_IsSubPathOf(const char *base,
+                      const char *path);
+
+Bool File_DoesVolumeSupportConvertBlocks(const char *pathName);
 
 /*
  *---------------------------------------------------------------------------
