@@ -1,5 +1,6 @@
 /*********************************************************
- * Copyright (C) 2003-2023 VMware, Inc. All rights reserved.
+ * Copyright (c) 2003-2024 Broadcom. All rights reserved.
+ * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -248,30 +249,40 @@ Max(int a, int b)
 #define PAGE_SHIFT_16KB  14
 #define PAGE_SHIFT_64KB  16
 
-#ifndef PAGE_SHIFT // {
+#define PAGE_SIZE_4KB    4096
+#define PAGE_SIZE_16KB   16384
+#define PAGE_SIZE_64KB   65536
+
 #if defined __x86_64__ || defined __i386__
-   #define PAGE_SHIFT    PAGE_SHIFT_4KB
+   #define VMW_PAGE_SHIFT PAGE_SHIFT_4KB
+   #define VMW_PAGE_SIZE  PAGE_SIZE_4KB
 #elif defined __APPLE__
    #if defined VM_ARM_ANY
-      #define PAGE_SHIFT    PAGE_SHIFT_16KB
+      #define VMW_PAGE_SHIFT PAGE_SHIFT_16KB
+      #define VMW_PAGE_SIZE  PAGE_SIZE_16KB
    #else
-      #define PAGE_SHIFT    PAGE_SHIFT_4KB
+      #define VMW_PAGE_SHIFT PAGE_SHIFT_4KB
+      #define VMW_PAGE_SIZE  PAGE_SIZE_4KB
    #endif
 #elif defined VM_ARM_64
-   #define PAGE_SHIFT    PAGE_SHIFT_4KB
+   #define VMW_PAGE_SHIFT PAGE_SHIFT_4KB
+   #define VMW_PAGE_SIZE  PAGE_SIZE_4KB
 #elif defined __arm__
-   #define PAGE_SHIFT    PAGE_SHIFT_4KB
+   #define VMW_PAGE_SHIFT PAGE_SHIFT_4KB
+   #define VMW_PAGE_SIZE  PAGE_SIZE_4KB
+#elif defined __wasm__
+   #define VMW_PAGE_SHIFT PAGE_SHIFT_4KB
+   #define VMW_PAGE_SIZE  PAGE_SIZE_4KB
 #else
-   #error
+   #error Could not determine page size information for this compiler.
 #endif
-#endif // }
 
-#define PAGE_SIZE_4KB    (1 << PAGE_SHIFT_4KB)
-#define PAGE_SIZE_16KB   (1 << PAGE_SHIFT_16KB)
-#define PAGE_SIZE_64KB   (1 << PAGE_SHIFT_64KB)
+#ifndef PAGE_SHIFT
+#define PAGE_SHIFT VMW_PAGE_SHIFT
+#endif
 
 #ifndef PAGE_SIZE
-#define PAGE_SIZE     (1 << PAGE_SHIFT)
+#define PAGE_SIZE     VMW_PAGE_SIZE
 #endif
 
 #define PAGE_MASK_4KB    (PAGE_SIZE_4KB - 1)
@@ -456,6 +467,16 @@ Max(int a, int b)
 #endif
 #define QWORD(_hi, _lo)   ((((uint64)(_hi)) << 32) | ((uint32)(_lo)))
 
+#ifndef HIDWORD128
+#define HIDWORD128(_qw)    ((uint64)((_qw) >> 64))
+#endif
+#ifndef LODWORD128
+#define LODWORD128(_qw)    ((uint64)(_qw))
+#endif
+#ifndef QWORD128
+#define QWORD128(_hi, _lo) ((((uint128)(_hi)) << 64) | ((uint64)(_lo)))
+#endif
+
 
 /*
  * Deposit a field _src at _pos bits from the right,
@@ -588,19 +609,74 @@ typedef int pid_t;
  * Convenience macros and definitions. Can often be used instead of #ifdef.
  */
 
+#ifdef VMK_HAS_VMM
+#define VMK_HAS_VMM_ONLY(...) __VA_ARGS__
+#else
+#define VMK_HAS_VMM_ONLY(...)
+#endif
+
+#if defined VMM || defined VMK_HAS_VMM
+/* Structure field only used to support the VMM (as opposed to the ULM). */
+#define VMM_ONLY_FIELD(name) name
+#else
+/*
+ * Structure field only used to support the VMM (as opposed to the ULM).
+ * Until VMK_HAS_VMM is retired, keep this field so the size of the structure
+ * is unchanged (was bug 3354277), but prepend an underscore to the field's
+ * name to verify at compile time that the field is indeed not used.
+ */
+#define VMM_ONLY_FIELD(name) _##name
+#endif
+
 #undef ARM64_ONLY
+#if defined(_MSC_VER)
+/*
+ * Old MSVC versions (such as MSVC 14.29.30133, used to build Workstation's
+ * offset checker) are notorious to have non-standard __VA_ARGS__ handling.
+ * The current latest Visual Studio 2022 17.10 (MSVC 19.40/_MSC_VER 1940)
+ * has not fixed the defect yet.
+ */
+#if defined(VMX86_DESKTOP) && (_MSC_VER > 1940)
+#pragma message("ERROR: Compiler version: " XSTR(_MSC_VER))
+#pragma message("ERROR: PR 3405101: Is __VA_ARGS__ hack needed for Arm & x86?")
+#endif
 #ifdef VM_ARM_64
-#define ARM64_ONLY(x)    x
+#define ARM64_ONLY(x) x
 #else
 #define ARM64_ONLY(x)
 #endif
+#else
+#ifdef VM_ARM_64
+#define ARM64_ONLY(...)  __VA_ARGS__
+#else
+#define ARM64_ONLY(...)
+#endif
+#endif
 
 #undef X86_ONLY
+#ifdef _MSC_VER
+/*
+ * Old MSVC versions (such as MSVC 14.29.30133, used to build Workstation's
+ * offset checker) are notorious to have non-standard __VA_ARGS__ handling.
+ * The current latest Visual Studio 2022 17.10 (MSVC 19.40/_MSC_VER 1940)
+ * has not fixed the defect yet.
+ */
+#if defined(VMX86_DESKTOP) && (_MSC_VER > 1940)
+#pragma message("ERROR: Compiler version: " XSTR(_MSC_VER))
+#pragma message("ERROR: PR 3405101: Is __VA_ARGS__ hack needed for Arm & x86?")
+#endif
 #ifdef VM_X86_ANY
 #define X86_ONLY(x)      x
 #else
 #define X86_ONLY(x)
 #endif
+#else
+#ifdef VM_X86_ANY
+#define X86_ONLY(...)    __VA_ARGS__
+#else
+#define X86_ONLY(...)
+#endif
+#endif
 
 #undef DEBUG_ONLY
 #ifdef VMX86_DEBUG
@@ -668,6 +744,12 @@ typedef int pid_t;
 #define HOSTED_ONLY(x) x
 #endif
 
+#ifdef VMX86_FDM
+#define vmx86_fdm 1
+#else
+#define vmx86_fdm 0
+#endif
+
 #ifdef VMX86_ESXIO
 #define vmx86_esxio      1
 #else
@@ -682,6 +764,12 @@ typedef int pid_t;
 #define VMKERNEL_ONLY(x)
 #endif
 
+#ifdef COMP_TEST
+#define vmx86_test   1
+#else
+#define vmx86_test   0
+#endif
+
 /*
  * In MSVC, _WIN32 is defined as 1 when the compilation target is
  * 32-bit ARM, 64-bit ARM, x86, or x64 (which implies _WIN64). This
@@ -765,11 +853,17 @@ typedef int pid_t;
 #else
 #define ulm_esx 0
 #endif
+#ifdef ULM_LIN
+#define ulm_lin 1
+#else
+#define ulm_lin 0
+#endif
 #else
 #define vmx86_ulm 0
 #define ulm_mac 0
 #define ulm_win 0
 #define ulm_esx 0
+#define ulm_lin 0
 #define ULM_ONLY(x)
 #endif
 
@@ -935,17 +1029,21 @@ typedef int pid_t;
 #define VMW_CLANG_ANALYZER_NORETURN() ((void)0)
 #endif
 
-/* VMW_FALLTHROUGH
+/*
+ * VMW_FALLTHROUGH
  *
- *   Instructs GCC 9 and above to not warn when a case label of a
+ *   Instructs capable compilers to not warn when a case label of a
  *   'switch' statement falls through to the next label.
  *
- *   If not GCC 9 or above, expands to nothing.
+ *   If not a matched compiler, expands to nothing.
  */
-#if __GNUC__ >= 9
-#define VMW_FALLTHROUGH() __attribute__((fallthrough))
+#if defined __cplusplus && __cplusplus >= 201703L
+   #define VMW_FALLTHROUGH() [[fallthrough]]
+#elif (defined(__GNUC__) && (__GNUC__ >= 9)) ||           \
+      (defined(__clang__) && (__clang_major__ >= 13))
+   #define VMW_FALLTHROUGH() __attribute__((fallthrough))
 #else
-#define VMW_FALLTHROUGH()
+   #define VMW_FALLTHROUGH()
 #endif
 
 #endif // ifndef _VM_BASIC_DEFS_H_
