@@ -1804,15 +1804,29 @@ TOOLS_VERSION_UINT_TO_COMPONENTS(const ToolsVersion toolsVersion,   // IN
 #define   TOOLS_VERSION_PLIERS_RELEASE_V_BASE 0
 
 #ifndef RC_INVOKED
-#define   TOOLS_VERSION_NEXT TOOLS_VERSION_TO_UINT(TOOLS_VERSION_NEXT_V)
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SWISS_ARMY_KNIFE_RELEASE_V)
 #endif /* RC_INVOKED */
-#define   TOOLS_VERSION_NEXT_V_MJR  13
-#define   TOOLS_VERSION_NEXT_V_MNR  0
-#define   TOOLS_VERSION_NEXT_V_BASE 0
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_RELEASE_V_MJR  13
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_RELEASE_V_MNR  0
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_RELEASE_V_BASE 0
 
-#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_NEXT
-#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_NEXT)
-#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_NEXT)
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_PATCH1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SWISS_ARMY_KNIFE_PATCH1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_PATCH1_V_MJR  13
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_PATCH1_V_MNR  0
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_PATCH1_V_BASE 1
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_UPDATE1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SWISS_ARMY_KNIFE_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_UPDATE1_V_MJR  13
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_UPDATE1_V_MNR  0
+#define   TOOLS_VERSION_SWISS_ARMY_KNIFE_UPDATE1_V_BASE 5
+
+#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_SWISS_ARMY_KNIFE_UPDATE1
+#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_SWISS_ARMY_KNIFE_UPDATE1)
+#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_SWISS_ARMY_KNIFE_UPDATE1)
 
 /*
  * The extended Tools version is the current Tools version with the
