@@ -1,5 +1,6 @@
 /*********************************************************
- * Copyright (C) 2008-2019 VMware, Inc. All rights reserved.
+ * Copyright (c) 2008-2024 Broadcom. All rights reserved.
+ * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -58,6 +59,12 @@
 #include "vmware/guestrpc/tclodefs.h"
 #include "err.h"
 #include "logToHost.h"
+#include "vthreadBase.h"
+#include "hostinfo.h"
+#include "vm_tools_version.h"
+#include "buildNumber.h"
+#include "vm_product.h"
+#include "util.h"
 
 #define LOGGING_GROUP         "logging"
 
@@ -116,6 +123,11 @@
    }                                               \
 } while (0)
 
+#define VMX_LOG_CMD     "log "
+#define VMX_LOG_CMD_LEN (sizeof(VMX_LOG_CMD) - 1)
+
+#define LOG_HEADER_MAX_ENTRIES 2
+
 
 typedef struct LogHandler {
    GlibLogger    *logger;
@@ -157,7 +169,6 @@ static guint gDroppedLogCount = 0;
 static gint gMaxCacheEntries = DEFAULT_MAX_CACHE_ENTRIES;
 static gboolean gEnableCoreDump = TRUE;
 static gboolean gLogEnabled = FALSE;
-static gboolean gGuestSDKMode = FALSE;
 static guint gPanicCount = 0;
 static LogHandler *gDefaultData;
 static LogHandler *gErrorData;
@@ -191,6 +202,9 @@ static RpcChannel *gChannel; /* either NULL or allocated AND started */
  */
 static GLogLevelFlags gLevelMask;
 
+static gchar *gLogHeaderBuf[LOG_HEADER_MAX_ENTRIES];
+static guint gLogHeaderCount;
+
 static enum RpcMode {
    RPC_OFF = 0,
    RPC_GUEST_LOG_TEXT,
@@ -209,6 +223,7 @@ static void LogWhereLevelV(LogWhere where,
                            const gchar *domain,
                            const gchar *fmt,
                            va_list args);
+static LogHandler *GetLogHandlerByDomain(const gchar *domain);
 
 /* Internal functions. */
 
@@ -259,7 +274,7 @@ VMToolsLogLevelString(GLogLevelFlags level) {
 
 
 /**
- * Aborts the program, optionally creating a core dump.
+ * Forces the program to quit, optionally creating a core dump.
  */
 
 static INLINE NORETURN void
@@ -368,7 +383,7 @@ VMTools_GetTimeAsString(void)
 /**
  * Creates a formatted message to be logged. The format of the message will be:
  *
- *    [timestamp] [domain] [level] Log message
+ *    [timestamp] [domain] [level] [thread_id] Log message
  *
  * @param[in] message      User log message.
  * @param[in] domain       Log domain.
@@ -417,31 +432,38 @@ VMToolsLogFormat(const gchar *message,
 
    if (!addsTimestamp) {
       if (shared) {
-         len = VMToolsAsprintf(&msg, "[%s] [%8s] [%s:%s] %s\n",
+         len = VMToolsAsprintf(&msg, "[%s] [%8s] [%s:%s] [%"FMT64"u] %s\n",
                                (tstamp != NULL) ? tstamp : "no time",
-                               slevel, gLogDomain, domain, message);
+                               slevel, gLogDomain, domain,
+                               VThreadBase_GetKernelID(), message);
       } else {
-         len = VMToolsAsprintf(&msg, "[%s] [%8s] [%s] %s\n",
+         len = VMToolsAsprintf(&msg, "[%s] [%8s] [%s] [%"FMT64"u] %s\n",
                                (tstamp != NULL) ? tstamp : "no time",
-                               slevel, domain, message);
+                               slevel, domain, VThreadBase_GetKernelID(),
+                               message);
       }
    } else {
       if (cached) {
          if (shared) {
-            len = VMToolsAsprintf(&msg, "[cached at %s] [%8s] [%s:%s] %s\n",
-                                  (tstamp != NULL) ? tstamp : "no time",
-                                  slevel, gLogDomain, domain, message);
+            len = VMToolsAsprintf(&msg,
+                              "[cached at %s] [%8s] [%s:%s] [%"FMT64"u] %s\n",
+                              (tstamp != NULL) ? tstamp : "no time", slevel,
+                              gLogDomain, domain, VThreadBase_GetKernelID(),
+                              message);
          } else {
-            len = VMToolsAsprintf(&msg, "[cached at %s] [%8s] [%s] %s\n",
-                                  (tstamp != NULL) ? tstamp : "no time",
-                                  slevel, domain, message);
+            len = VMToolsAsprintf(&msg,
+                               "[cached at %s] [%8s] [%s] [%"FMT64"u] %s\n",
+                               (tstamp != NULL) ? tstamp : "no time", slevel,
+                               domain, VThreadBase_GetKernelID(), message);
          }
       } else {
          if (shared) {
-            len = VMToolsAsprintf(&msg, "[%8s] [%s:%s] %s\n",
-                                  slevel, gLogDomain, domain, message);
+            len = VMToolsAsprintf(&msg, "[%8s] [%s:%s] [%"FMT64"u] %s\n",
+                                  slevel, gLogDomain, domain,
+                                  VThreadBase_GetKernelID(), message);
          } else {
-            len = VMToolsAsprintf(&msg, "[%8s] [%s] %s\n", slevel, domain, message);
+            len = VMToolsAsprintf(&msg, "[%8s] [%s] [%"FMT64"u] %s\n", slevel,
+                                  domain, VThreadBase_GetKernelID(), message);
          }
       }
    }
@@ -486,6 +508,31 @@ VMToolsFreeLogEntry(gpointer data)
 }
 
 
+/**
+ * Function that logs a cached log header of Tools version, build details
+ * and Guest OS details.
+ *
+ * @param[in] _data     LogEntry pointer.
+ */
+
+static void
+VMToolsLogHeader(gpointer _data)
+{
+   LogEntry *entry = _data;
+   GlibLogger *logger = entry->handler->logger;
+   guint i;
+
+   for (i = 0; i < gLogHeaderCount; i++) {
+      char *message = VMToolsLogFormat(gLogHeaderBuf[i], entry->domain,
+                                       G_LOG_LEVEL_MESSAGE, entry->handler,
+                                       FALSE);
+
+      logger->logfn(entry->domain, G_LOG_LEVEL_MESSAGE, message, logger);
+      g_free(message);
+   }
+}
+
+
 /**
  * Function that calls the log handler.
  *
@@ -503,6 +550,10 @@ VMToolsLogMsg(gpointer _data, gpointer userData)
    gboolean usedSyslog = FALSE;
 
    if (logger != NULL) {
+       if (logger->logHeader) {
+          VMToolsLogHeader(entry);
+          logger->logHeader = FALSE;
+       }
        logger->logfn(entry->domain, entry->level, entry->msg, logger);
        usedSyslog = entry->handler->isSysLog;
    } else if (gErrorData->logger != NULL) {
@@ -610,14 +661,9 @@ VMToolsLogInt(const gchar *domain,
       data = data->inherited ? gDefaultData : data;
 
       entry = g_malloc0(sizeof(LogEntry));
-      if (entry) {
-         entry->domain = domain ? g_strdup(domain) : NULL;
-         if (domain && !entry->domain) {
-            VMToolsLogPanic();
-         }
-         entry->handler = data;
-         entry->level = level;
-      }
+      entry->domain = g_strdup(domain);
+      entry->handler = data;
+      entry->level = level;
 
       if (gLogIOSuspended && data->needsFileIO) {
          if (gMaxCacheEntries == 0) {
@@ -856,10 +902,9 @@ VMToolsGetLogFilePath(const gchar *key,
                       GKeyFile *cfg)
 {
    gsize len = 0;
-   gchar *path = NULL;
    gchar *origPath = NULL;
+   gchar *path = g_key_file_get_string(cfg, LOGGING_GROUP, key, NULL);
 
-   path = g_key_file_get_string(cfg, LOGGING_GROUP, key, NULL);
    if (path == NULL) {
       return VMToolsDefaultLogFilePath(domain);
    }
@@ -884,6 +929,11 @@ VMToolsGetLogFilePath(const gchar *key,
    if (len == 0) {
       g_warning("Invalid path for domain '%s'.", domain);
       g_free(origPath);
+      /*
+       * Coverity flags this as a possible copy-paste error but assigning
+       * to path rather than origPath is correct.
+       */
+      /* coverity[copy_paste_error] */
       path = NULL;
    } else {
       /* Drop the trailing '"' chars */
@@ -1016,7 +1066,7 @@ VMToolsGetLogHandler(const gchar *handler,
    logger->type = strdup(handler);
    logger->needsFileIO = needsFileIO;
    logger->isSysLog = isSysLog;
-   logger->confData = (path != NULL ? g_strdup(path) : NULL);
+   logger->confData = g_strdup(path);
    g_free(path);
 
    return logger;
@@ -1407,6 +1457,7 @@ VMToolsConfigLoggingInt(const gchar *defaultDomain,
    GPtrArray *oldDomains = NULL;
    LogHandler *oldDefault = NULL;
    GError *err = NULL;
+   char *gosDetails;
 
    g_return_if_fail(defaultDomain != NULL);
 
@@ -1480,6 +1531,34 @@ VMToolsConfigLoggingInt(const gchar *defaultDomain,
    gLogEnabled |= force;
    MarkLogInitialized();
 
+   /*
+    * Cache Tools version, build number and guest OS details.
+    * Cached log headers will be logged at log rotation and reset.
+    * No need to re-init the log headers in case of config reload.
+    */
+   if (gLogHeaderCount == 0) {
+      LogHandler *handler = GetLogHandlerByDomain(gLogDomain);
+      GlibLogger *logger = handler->logger;
+
+      logger->logHeader = TRUE;
+
+      gLogHeaderBuf[gLogHeaderCount++] = Str_Asprintf(NULL,
+                                                      "%s Version: %s (%s)",
+                                                      VMWARE_TOOLS_SHORT_NAME,
+                                                      TOOLS_VERSION_EXT_CURRENT_STR,
+                                                      BUILD_NUMBER);
+
+      gosDetails = Hostinfo_GetOSDetailedData();
+      if (gosDetails != NULL && gLogHeaderCount < LOG_HEADER_MAX_ENTRIES) {
+         gLogHeaderBuf[gLogHeaderCount++] = Str_Asprintf(NULL,
+                                                         "Guest OS details: %s",
+                                                         gosDetails);
+      }
+      free(gosDetails);
+
+      ASSERT(gLogHeaderCount <= LOG_HEADER_MAX_ENTRIES);
+   }
+
    gMaxCacheEntries = g_key_file_get_integer(cfg, LOGGING_GROUP,
                                              "maxCacheEntries", &err);
    if (err != NULL || gMaxCacheEntries < 0) {
@@ -1513,8 +1592,17 @@ VMToolsConfigLoggingInt(const gchar *defaultDomain,
    /* If needed, restore the old configuration. */
    if (!reset) {
       if (oldDomains != NULL) {
+         guint i;
+         for (i = 0; i < oldDomains->len; i++) {
+            LogHandler *old = g_ptr_array_index(oldDomains, i);
+            CLEAR_LOG_HANDLER(old);
+         }
          g_ptr_array_free(oldDomains, TRUE);
       }
+      if (oldDefault != NULL && oldDefault != gDefaultData) {
+         CLEAR_LOG_HANDLER(oldDefault);
+         oldDefault = NULL;
+      }
    }
 
    /*
@@ -1670,7 +1758,7 @@ VMToolsLogWrapper(GLogLevelFlags level,
          free(msg);
       }
    } else {
-      /* Try to avoid malloc() since we're aborting. */
+      /* Try to avoid malloc() since we're forcibly quitting. */
       gchar msg[256];
       Str_Vsnprintf(msg, sizeof msg, fmt, args);
       VMToolsLogInt(gLogDomain, level, msg, gDefaultData);
@@ -1740,7 +1828,8 @@ DestroyRpcChannel(void)
 
    gChannel = NULL;
 
-   g_debug("RPCI Channel for logging is destroyed successfully.\n");
+   /* Fix log recursion issue, check bug: 2607084 for more details */
+   Debug("RPCI Channel for logging is destroyed successfully.\n");
 }
 
 
@@ -2099,17 +2188,6 @@ VMTools_ResumeLogIO()
 }
 
 
-/**
- * Called if vmtools lib is used along with Guestlib SDK.
- */
-
-void
-VMTools_SetGuestSDKMode(void)
-{
-   gGuestSDKMode = TRUE;
-}
-
-
 /**
  * Logs a message using the G_LOG_LEVEL_DEBUG level.
  *
@@ -2121,16 +2199,12 @@ Debug(const char *fmt, ...)
 {
    va_list args;
    va_start(args, fmt);
-   if (gGuestSDKMode) {
-      GuestSDK_Debug(fmt, args);
-   } else {
-      /*
-       * Preserve errno/lastError.
-       * This keeps compatibility with bora/lib Log(), preventing
-       * Log() calls in bora/lib code from clobbering errno/lastError.
-       */
-      WITH_ERRNO(err, VMToolsLogWrapper(G_LOG_LEVEL_DEBUG, fmt, args));
-   }
+   /*
+    * Preserve errno/lastError.
+    * This keeps compatibility with bora/lib Log(), preventing
+    * Log() calls in bora/lib code from clobbering errno/lastError.
+    */
+   WITH_ERRNO(err, VMToolsLogWrapper(G_LOG_LEVEL_DEBUG, fmt, args));
    va_end(args);
 }
 
@@ -2146,16 +2220,12 @@ Log(const char *fmt, ...)
 {
    va_list args;
    va_start(args, fmt);
-   if (gGuestSDKMode) {
-      GuestSDK_Log(fmt, args);
-   } else {
-      /*
-       * Preserve errno/lastError.
-       * This keeps compatibility with bora/lib Log(), preventing
-       * Log() calls in bora/lib code from clobbering errno/lastError.
-       */
-      WITH_ERRNO(err, VMToolsLogWrapper(G_LOG_LEVEL_INFO, fmt, args));
-   }
+   /*
+    * Preserve errno/lastError.
+    * This keeps compatibility with bora/lib Log(), preventing
+    * Log() calls in bora/lib code from clobbering errno/lastError.
+    */
+    WITH_ERRNO(err, VMToolsLogWrapper(G_LOG_LEVEL_INFO, fmt, args));
    va_end(args);
 }
 
@@ -2232,33 +2302,29 @@ Panic(const char *fmt, ...)
 
    va_start(args, fmt);
 
-   if (gGuestSDKMode) {
-      GuestSDK_Panic(fmt, args);
-   } else {
-      if (gPanicCount == 0) {
-         char *msg = Str_Vasprintf(NULL, fmt, args);
-         if (msg != NULL) {
-            g_log(gLogDomain, G_LOG_LEVEL_ERROR, "%s", msg);
-            free(msg);
-         }
-         /*
-          * In case an user-installed custom handler doesn't panic on error,
-          * force a core dump. Also force a dump in the recursive case.
-          */
-         VMToolsLogPanic();
-      } else if (gPanicCount == 1) {
-         /*
-          * Use a stack allocated string since we're in a recursive panic, so
-          * probably already in a weird state.
-          */
-         gchar msg[1024];
-         Str_Vsnprintf(msg, sizeof msg, fmt, args);
-         fprintf(stderr, "Recursive panic: %s\n", msg);
-         VMToolsLogPanic();
-      } else {
-         fprintf(stderr, "Recursive panic, giving up.\n");
-         exit(-1);
+   if (gPanicCount == 0) {
+      char *msg = Str_Vasprintf(NULL, fmt, args);
+      if (msg != NULL) {
+         g_log(gLogDomain, G_LOG_LEVEL_ERROR, "%s", msg);
+         free(msg);
       }
+      /*
+       * In case an user-installed custom handler doesn't panic on error,
+       * force a core dump. Also force a dump in the recursive case.
+       */
+      VMToolsLogPanic();
+   } else if (gPanicCount == 1) {
+      /*
+       * Use a stack allocated string since we're in a recursive panic, so
+       * probably already in a weird state.
+       */
+      gchar msg[1024];
+      Str_Vsnprintf(msg, sizeof msg, fmt, args);
+      fprintf(stderr, "Recursive panic: %s\n", msg);
+      VMToolsLogPanic();
+   } else {
+      fprintf(stderr, "Recursive panic, giving up.\n");
+      exit(-1);
    }
    va_end(args);
    while (1) ; // avoid compiler warning
@@ -2281,16 +2347,12 @@ Warning(const char *fmt, ...)
 {
    va_list args;
    va_start(args, fmt);
-   if (gGuestSDKMode) {
-      GuestSDK_Warning(fmt, args);
-   } else {
-      /*
-       * Preserve errno/lastError.
-       * This keeps compatibility with bora/lib Log(), preventing
-       * Log() calls in bora/lib code from clobbering errno/lastError.
-       */
-      WITH_ERRNO(err, VMToolsLogWrapper(G_LOG_LEVEL_WARNING, fmt, args));
-   }
+   /*
+    * Preserve errno/lastError.
+    * This keeps compatibility with bora/lib Log(), preventing
+    * Log() calls in bora/lib code from clobbering errno/lastError.
+    */
+   WITH_ERRNO(err, VMToolsLogWrapper(G_LOG_LEVEL_WARNING, fmt, args));
    va_end(args);
 }
 
@@ -2349,12 +2411,8 @@ WarningToHost(const char *fmt, ...)
 {
    va_list args;
    va_start(args, fmt);
-   if (gGuestSDKMode) {
-      GuestSDK_Warning(fmt, args);
-   } else {
-      WITH_ERRNO(err,
-         VmwareLogWrapper(TO_HOST, G_LOG_LEVEL_WARNING, fmt, args));
-   }
+   WITH_ERRNO(err,
+      VmwareLogWrapper(TO_HOST, G_LOG_LEVEL_WARNING, fmt, args));
    va_end(args);
 }
 
@@ -2375,12 +2433,8 @@ WarningToGuest(const char *fmt, ...)
 {
    va_list args;
    va_start(args, fmt);
-   if (gGuestSDKMode) {
-      GuestSDK_Warning(fmt, args);
-   } else {
-      WITH_ERRNO(err,
-         VmwareLogWrapper(IN_GUEST, G_LOG_LEVEL_WARNING, fmt, args));
-   }
+   WITH_ERRNO(err,
+      VmwareLogWrapper(IN_GUEST, G_LOG_LEVEL_WARNING, fmt, args));
    va_end(args);
 }
 
@@ -2422,7 +2476,6 @@ VMTools_ChangeLogFilePath(const gchar *delimiter,     // IN
 {
    gchar key[128];
    gchar *path = NULL;
-   gchar *userLogTemp = NULL;
    gchar **tokens;
    gboolean retVal = FALSE;
 
@@ -2439,8 +2492,9 @@ VMTools_ChangeLogFilePath(const gchar *delimiter,     // IN
 
    tokens = g_strsplit(path, delimiter, 2);
    if (tokens != NULL && *tokens != NULL){
-      userLogTemp = g_strjoin(appendString, *tokens, " ", NULL);
-      userLogTemp = g_strchomp (userLogTemp);
+      char *userLogTemp = g_strjoin(appendString, *tokens, " ", NULL);
+
+      g_strchomp(userLogTemp);
       if (*(tokens+1) != NULL){
          gchar *userLog;
          userLog = g_strjoin(delimiter, userLogTemp, *(tokens+1), NULL);
@@ -2574,7 +2628,7 @@ VMTools_SetupVmxGuestLog(gboolean refreshRpcChannel,   // IN
     */
    g_rec_mutex_lock(&gVmxGuestLogMutex);
 
-   /* Load config for the kill switch in tools.conf */
+   /* Load config for the disable-switch in tools.conf */
    if (NULL == cfg) {
       if (!VMTools_LoadConfig(NULL, G_KEY_FILE_NONE, &cfg, NULL)) {
          g_warning("Failed to load the tools config file.\n");
@@ -2595,6 +2649,43 @@ done:
 }
 
 
+/*
+ *******************************************************************************
+ * VMTools_TeardownVmxGuestLog --                                         */ /**
+ *
+ * Destroy the dedicated RPCI channel set up for the Vmx Guest Logging.
+ * This function is called from the tools process exit code path.
+ *
+ *******************************************************************************
+ */
+
+void
+VMTools_TeardownVmxGuestLog(void)
+{
+   /*
+    * In case VMTools_UseVmxGuestLog() is never called.
+    */
+   if (!gUseVmxGuestLog) {
+      return;
+   }
+
+   /*
+    * Acquire the same locks as VMTools_SetupVmxGuestLog.
+    * Stop the glib based logging to avoid nested logging
+    * from RpcChannel error.
+    */
+   VMTools_AcquireLogStateLock();
+   StopGlibLogging();
+   g_rec_mutex_lock(&gVmxGuestLogMutex);
+
+   DestroyRpcChannel();
+
+   g_rec_mutex_unlock(&gVmxGuestLogMutex);
+   RestartGlibLogging();
+   VMTools_ReleaseLogStateLock();
+}
+
+
 /**
  * Helper function to return the matching LogHandler for a domain name
  *
@@ -2697,3 +2788,113 @@ VMTools_Log(LogWhere where,
    LogWhereLevelV(where, level, domain, fmt, args);
    va_end(args);
 }
+
+
+/*
+ ******************************************************************************
+ * VMToolsVmxLogV --
+ *
+ * Sends the log message through RPC to vmx to be logged on the host.
+ * Also, logs the message to vmsvc log file inside guest.
+ *
+ * @param[in]  chan         The RPC channel instance.
+ * @param[in]  fmt          Log message output format.
+ * @param[in]  args         The argument list.
+ *
+ * @return None
+ *
+ ******************************************************************************
+ */
+
+static void
+VMToolsVmxLogV(RpcChannel *chan,
+               const gchar *fmt,
+               va_list args)
+{
+   char *reply = NULL;
+   size_t replyLen;
+   gchar msg[4096] = VMX_LOG_CMD;
+   gint len;
+
+   len = g_vsnprintf(msg + VMX_LOG_CMD_LEN,
+                     sizeof msg - VMX_LOG_CMD_LEN,
+                     fmt, args);
+
+   if (len <= 0) {
+      g_warning("%s: g_vsnprintf failed: return value: %d.\n", __FUNCTION__,
+                len);
+      return;
+   }
+
+   len += VMX_LOG_CMD_LEN;
+   if (len >= sizeof msg) {
+      len = sizeof msg - 1;
+      msg[len] = '\0';
+   }
+
+   if (!RpcChannel_Send(chan, msg, len + 1, &reply, &replyLen)) {
+      g_warning("%s: Error sending RPC message: %s. reply: %s\n",
+                __FUNCTION__, msg, VM_SAFE_STR(reply));
+   }
+   free(reply);
+
+   g_message("%s\n", msg + VMX_LOG_CMD_LEN);
+}
+
+
+/*
+ ******************************************************************************
+ * VMTools_VmxLog --
+ *
+ * Passes through VMToolsVmxLogV but takes the arguments inline.
+ *
+ * @param[in]  chan         The RPC channel instance.
+ * @param[in]  fmt          Log message output format.
+ *
+ * @return None
+ *
+ ******************************************************************************
+ */
+
+void
+VMTools_VmxLog(RpcChannel *chan,
+               const gchar *fmt,
+               ...)
+{
+   va_list args;
+
+   va_start(args, fmt);
+   VMToolsVmxLogV(chan, fmt, args);
+   va_end(args);
+}
+
+
+/*
+ ******************************************************************************
+ * VMTools_VmxLogThrottled --
+ *
+ * Passes through VMToolsVmxLogV to log the message after checking for the
+ * throttling condition. Takes the arguments inline.
+ *
+ * @param[in/out]  count     Throttle count.
+ * @param[in]      chan      The RPC channel instance.
+ * @param[in]      fmt       Log message output format.
+ *
+ * @return None
+ *
+ ******************************************************************************
+ */
+
+void
+VMTools_VmxLogThrottled(uint32 *count,
+                        RpcChannel *chan,
+                        const gchar *fmt,
+                        ...)
+{
+   va_list args;
+   if (Util_Throttle(++*count)) {
+      va_start(args, fmt);
+      VMToolsVmxLogV(chan, fmt, args);
+      va_end(args);
+   }
+}
