@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (c) 2016-2020,2022 VMware, Inc. All rights reserved.
+ * Copyright (c) 2016-2020,2022-2023 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -635,6 +635,9 @@ main(int argc, char *argv[])
 
 #if defined(_WIN32)
    WinUtil_EnableSafePathSearching(TRUE);
+#if defined(VMX86_RELEASE)
+   WinUtil_VerifyExePathW();
+#endif
 #endif
 
    gAppName = g_path_get_basename(argv[0]);
