@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2016 VMware, Inc. All rights reserved.
+ * Copyright (C) 2016-2021 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -42,12 +42,4 @@ static inline void resolutionDRMClose(int fd) {}
 
 #endif /* !ENABLE_RESOLUTIONKMS */
 
-int
-resolutionXorgDriverVersion(int numPaths,
-			    const char *paths[],
-			    const char versionString[],
-			    int *major,
-			    int *minor,
-			    int *level);
-
 #endif /*  _RESOLUTION_COMMON_H_ */
