@@ -1,5 +1,6 @@
 /*********************************************************
- * Copyright (C) 2011-2017 VMware, Inc. All rights reserved.
+ * Copyright (c) 2011-2025 Broadcom. All Rights Reserved.
+ * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -409,13 +410,18 @@ VGAuth_ValidateSSPIResponse(VGAuthContext *ctx,
  *        authenticated.</li>
  * </ol>
  *
- * @remark One @a extraParams is supported:
+ * @remark Supported @a extraParams:
  *         VGAUTH_PARAM_VALIDATE_INFO_ONLY, which must have the value
  *         VGAUTH_PARAM_VALUE_TRUE or VGAUTH_PARAM_VALUE_FALSE.
  *         If set, SAML token validation is done, but the returned
  *         @a handle cannot be used for impersonation or ticket
  *         creation.
  *
+ *         VGAUTH_PARAM_SAML_HOST_VERIFIED, which must have the value
+ *         VGAUTH_PARAM_VALUE_TRUE or VGAUTH_PARAM_VALUE_FALSE.
+ *         If set, the SAML token has been verified by the host
+ *         and this service will skip that step when validating.
+ *
  * @param[in]  ctx            The VGAuthContext.
  * @param[in]  samlToken      The SAML token to be validated.
  * @param[in]  userName       The user to authenticate as. Optional.
@@ -453,6 +459,7 @@ VGAuth_ValidateSamlBearerToken(VGAuthContext *ctx,
    VGAuthError err;
    VGAuthUserHandle *newHandle = NULL;
    gboolean validateOnly;
+   gboolean hostVerified;
 
    /*
     * arg check
@@ -491,9 +498,17 @@ VGAuth_ValidateSamlBearerToken(VGAuthContext *ctx,
    if (VGAUTH_E_OK != err) {
       return err;
    }
+   err = VGAuthGetBoolExtraParam(numExtraParams, extraParams,
+                                 VGAUTH_PARAM_SAML_HOST_VERIFIED,
+                                 FALSE,
+                                 &hostVerified);
+   if (VGAUTH_E_OK != err) {
+      return err;
+   }
 
    err = VGAuth_SendValidateSamlBearerTokenRequest(ctx,
                                                    validateOnly,
+                                                   hostVerified,
                                                    samlToken,
                                                    userName,
                                                    &newHandle);
@@ -529,8 +544,7 @@ done:
  * @param[in]  password       The password to be validated.
  * @param[in]  numExtraParams The number of elements in extraParams.
  * @param[in]  extraParams    Any optional, additional paramaters to the
- *                            function. Currently none are supported, so this
- *                            must be NULL.
+ *                            function.
  * @param[out] handle         The resulting handle representing the user
  *                            associated with @a userName.
  *                            Must be freed with VGAuth_UserHandleFree().
@@ -546,7 +560,7 @@ VGAuthError
 VGAuth_ValidateUsernamePassword(VGAuthContext *ctx,
                                 const char *userName,
                                 const char *password,
-                                int numExtraParams,
+                                const int numExtraParams,
                                 const VGAuthExtraParams *extraParams,
                                 VGAuthUserHandle **handle)
 {
@@ -573,14 +587,15 @@ VGAuth_ValidateUsernamePassword(VGAuthContext *ctx,
       return VGAUTH_E_INVALID_ARGUMENT;
    }
 
-   err = VGAuthValidateExtraParams(numExtraParams, extraParams);
-   if (VGAUTH_E_OK != err) {
-      return err;
-   }
-
+   /*
+    * numExtraParams and extraParams need to be validated before use.  No need
+    * to validate them here since they're just passed through.
+    */
    err = VGAuthValidateUsernamePasswordImpl(ctx,
                                             userName,
                                             password,
+                                            numExtraParams,
+                                            extraParams,
                                             handle);
 
    if (VGAUTH_E_OK == err) {
